==> libspiff-0.6.2rc1.tar.gz: libspiff-0.6.2rc1/include/spiff/SpiffReaderCallback.h <==
/*
 * libSpiff - XSPF playlist handling library
 *
 * Copyright (C) 2007, Sebastian Pipping / Xiph.Org Foundation
 * All rights reserved.
 *
 * Redistribution  and use in source and binary forms, with or without
 * modification,  are permitted provided that the following conditions
 * are met:
 *
 *     * Redistributions   of  source  code  must  retain  the   above
 *       copyright  notice, this list of conditions and the  following
 *       disclaimer.
 *
 *     * Redistributions  in  binary  form must  reproduce  the  above
 *       copyright  notice, this list of conditions and the  following
 *       disclaimer   in  the  documentation  and/or  other  materials
 *       provided with the distribution.
 *
 *     * Neither  the name of the Xiph.Org Foundation nor the names of
 *       its  contributors may be used to endorse or promote  products
 *       derived  from  this software without specific  prior  written
 *       permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS  IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT  NOT
 * LIMITED  TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND  FITNESS
 * FOR  A  PARTICULAR  PURPOSE ARE DISCLAIMED. IN NO EVENT  SHALL  THE
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL,    SPECIAL,   EXEMPLARY,   OR   CONSEQUENTIAL   DAMAGES
 * (INCLUDING,  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES;  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT  LIABILITY,  OR  TORT (INCLUDING  NEGLIGENCE  OR  OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * Sebastian Pipping, dllmain@xiph.org
 */

/**
 * @file SpiffReaderCallback.h
 * Interface of SpiffReaderCallback.
 */

#ifndef SPIFF_READER_CALLBACK_H
#define SPIFF_READER_CALLBACK_H

namespace Spiff {



class SpiffProps;
class SpiffTrack;
class SpiffReader;



/**
 * Is called by a reader when new pieces of information
 * become available.
 */
class SpiffReaderCallback {

private:
	/**
	 * Is called when a new, complete track is available.
	 * Deleting <c>track</c> is up to you.
	 *
	 * @param track		New track, never <c>NULL</c>
	 */
	virtual void addTrack(SpiffTrack * track) = 0;

	/**
	 * Is called when all playlist properties are available.
	 * Deleting <c>props</c> is up to you.
	 *
	 * @param props		Playlist properties, never <c>NULL</c>
	 */
	virtual void setProps(SpiffProps * props) = 0;

	friend class SpiffReader;

};



}

#endif // SPIFF_READER_CALLBACK_H

==> libspiff-0.6.3.tar.gz: libspiff-0.6.3/include/spiff/SpiffReaderCallback.h <==
/*
 * libSpiff - XSPF playlist handling library
 *
 * Copyright (C) 2007, Sebastian Pipping / Xiph.Org Foundation
 * All rights reserved.
 *
 * Redistribution  and use in source and binary forms, with or without
 * modification,  are permitted provided that the following conditions
 * are met:
 *
 *     * Redistributions   of  source  code  must  retain  the   above
 *       copyright  notice, this list of conditions and the  following
 *       disclaimer.
 *
 *     * Redistributions  in  binary  form must  reproduce  the  above
 *       copyright  notice, this list of conditions and the  following
 *       disclaimer   in  the  documentation  and/or  other  materials
 *       provided with the distribution.
 *
 *     * Neither  the name of the Xiph.Org Foundation nor the names of
 *       its  contributors may be used to endorse or promote  products
 *       derived  from  this software without specific  prior  written
 *       permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS  IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT  NOT
 * LIMITED  TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND  FITNESS
 * FOR  A  PARTICULAR  PURPOSE ARE DISCLAIMED. IN NO EVENT  SHALL  THE
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL,    SPECIAL,   EXEMPLARY,   OR   CONSEQUENTIAL   DAMAGES
 * (INCLUDING,  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES;  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT  LIABILITY,  OR  TORT (INCLUDING  NEGLIGENCE  OR  OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * Sebastian Pipping, dllmain@xiph.org
 */

/**
 * @file SpiffReaderCallback.h
 * Interface of SpiffReaderCallback.
 */

#ifndef SPIFF_READER_CALLBACK_H
#define SPIFF_READER_CALLBACK_H

namespace Spiff {



class SpiffProps;
class SpiffTrack;
class SpiffReader;



/**
 * Is called by a reader when new pieces of information
 * become available.
 */
class SpiffReaderCallback {

public:
	/**
	 * Creates a new reader callback.
	 */
	SpiffReaderCallback();

	/**
	 * Destroys this reader callback.
	 */
	virtual ~SpiffReaderCallback();

private:
	/**
	 * Is called when a new, complete track is available.
	 * Deleting <c>track</c> is up to you.
	 *
	 * @param track		New track, never <c>NULL</c>
	 */
	virtual void addTrack(SpiffTrack * track);

	/**
	 * Is called when all playlist properties are available.
	 * Deleting <c>props</c> is up to you.
	 *
	 * @param props		Playlist properties, never <c>NULL</c>
	 */
	virtual void setProps(SpiffProps * props);

	friend class SpiffReader;

};



}

#endif // SPIFF_READER_CALLBACK_H
